/**
 * The plugin to add login capabilities to the
 * {@link Ext.container.Viewport viewport}.
 *
 * The URLs:
 *
 *      Login           → /application/admin
 *      Change password → /application/default/user/change_password
 *      Logout          → /application/default/user/logout
 *
 * @uses App.container.Viewport
 *
 */
Ext.define('App.container.plugin.Login', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pViewportLogin',

    // Private properties for internationalization
    textChangePwd: "Change password...",
    textLogin: "Login...",
    textLogout: "Exit the application",

    /**
     * Initialize the plugin.
     *
     * @param {App.container.Viewport} viewport
     */
    init: function (viewport) {

        "use strict";

        var inhibit_login = false,
            inhibit_logout = true,
            tbar = viewport.getComponent('topBar'),
            url = location.protocol + "//" + location.host + "/" + App.name;

        if (viewport.logged) {
            inhibit_login = true;
            inhibit_logout = false;
        }

        tbar.add('->', '-');

        tbar.add({
            hidden: inhibit_login,
            href: url + "/admin",
            hrefTarget: "_self",
            iconCls: 'xuser-identity',
            tooltip: this.textLogin
        });

        tbar.add({
            hidden: inhibit_logout,
            href: url + "/default/user/change_password",
            hrefTarget: "_self",
            text: this.textChangePwd,
            scale: "small"
        });

        if (inhibit_login) {
            tbar.add('-');
        }

        tbar.add({
            hidden: inhibit_logout,
            href: url + "/default/user/logout",
            hrefTarget: "_self",
            iconCls: 'xapplication-exit',
            tooltip: this.textLogout
        });

        tbar.setVisible(true);
    }
});