/**
 * The plugin for the App.form.Panel which activate tooltip
 * associated to each field.
 * It can be used with App.form.Panel and Ext.form.FieldSet.
 *
 * **Note**: the text of the tooltip is defined in the custom
 * field configuration option: *tipText*.
 *
 */
Ext.define('App.form.plugin.ToolTip', {

    extend: 'Ext.AbstractPlugin',
    alias: 'plugin.pFormToolTip',

    /**
     * Initialize the plugin.
     *
     * @param {Ext.form.Panel} form
     *
     */
    init: function (form) {

        "use strict";

        var fields;

        function createToolTip(c) {

            Ext.tip.QuickTipManager.register({
                target: c.id,
                title: c.fieldLabel,
                text: c.tipText,
                width: 200
            });
        }

        if (form instanceof Ext.form.Panel) {
            fields = form.getForm().getFields();

        } else {
            fields = form.items;
        }

        fields.each(function (field) {
            if (field.tipText) {
                field.on('render', createToolTip);
            }
        });
    }
});