/**
 * A dropdown menu providing two actions: Reset and Export to CSV file.
 * It is associated to the App.grid.Panel.
 *
 * This is private class to be used in the App.panel.Grid tool bars.
 *
 */
Ext.define('App.grid.button.ExpertMenu', {

    extend: 'Ext.button.Split',
    alias: 'widget.xgridbuttonexpertmenu',

    /*
     * @cfg {App.panel.Grid} grid (required)
     */

    // short cuts
    buttonMathJax: null,

    // Private properties for internationalisation
    textExport: 'Export to CSV file',
    textMathJax: 'Render equations',
    textReset: 'Reset',

    // private method requests by the component model of ExtJS
    initComponent: function () {

        var pMathJax,
            tableName = App.getTableName(this.grid.getStore());

        // the menu configuration
        this.menu = {
            items: [{
                itemId: 'buttonReset',
                listeners: {click: this.onReset, scope: this},
                text: this.textReset

            }, {
                href: App.csvUrl + '?tableName=' + tableName,
                itemId: 'buttonExport',
                text: this.textExport
            }]
        };

        // add check item to activate deactivate MathJax processing
        pMathJax = this.grid.findPlugin('pMathJax');
        if (pMathJax) {
            this.menu.items.push({
                checked: pMathJax.activated,
                itemId: 'buttonMathJax',
                text: this.textMathJax,
                xtype: 'menucheckitem'
            });
        }

        // initialise the base class
        this.callParent(arguments);

        // process checkItem event
        if (pMathJax) {
            this.buttonMathJax = this.menu.getComponent('buttonMathJax');
            this.buttonMathJax.on('checkchange', this.onCheckItemChange, pMathJax);
        }
    },

    /**
     * Activate /deactivate the MathJax processing.
     * Private handler used by the expert menu.
     *
     * @param {Ext.menu.CheckItem} menuItem
     * @param {Boolean} checked
     * @param {Object} eOpts
     *
     */
    onCheckItemChange: function (menuItem, checked, eOpts) {

        "use strict";

        var pMathJax = this;

        pMathJax.activated = checked;

        // process equation
        if (checked) {
            pMathJax.onProcessMath();

        // refresh the grid
        } else {
            pMathJax.getCmp().getView().refresh();
        }
    },

    /**
     * Handler to reset the grid
     *
     */
    onReset: function () {

        "use strict";
        this.grid.reset();
    }
});
