/**
 * A {alink Ext.panel.Panel panel} configure with the
 * {@link Ext.layout.container.Border border} layout splitting the space in
 * two parts. The first one contains the {@link App.grid.Panel grid}
 * and the second one the {@link App.grid.Filter grid filter}.
 *
 */
Ext.define('App.panel.GridWithFilter', {

    extend: 'App.panel.BaseWithSelector',
    alias: 'widget.xgridwithfilter',
    requires: [
        'App.grid.Filter',
        'App.grid.Panel',
        'Ext.LoadMask'
    ],

    // private short cuts
    filter: null,
    grid: null,

    // Private properties for internationalization
    textLoad: 'Loading...',

    // private method require by the Ext JS component model
    initComponent: function () {

        // initialise the base class
        this.callParent(arguments);

        // bind the filter to the grid
        this.filter = this.selectorPanel.child('xgridfilter');
        this.grid = this.mainPanel.child('xgrid');
        this.filter.bind(this.grid);

        // connect buttons
        this.goButton.hide();
        this.resetButton.on('click', this.filter.onReset, this.filter);

        // collapse the selectorPanel
        this.selectorPanel.collapsed = true;

        // Mask the GridFilter during loading
        this.grid.getView().loadMask = Ext.create('Ext.LoadMask', {
            msg: this.textLoad,
            target: this,
            store: this.grid.store
        });
    },

    // private method requires by the Ext JS component model
    beforeDestroy: function () {

        this.resetButton.un('click', this.filter.onReset, this.filter);
        this.callParent(arguments);
    }
});